use std::process::{Command, Stdio};

pub fn start_command(server_name: &str) -> Result<(), Box<dyn std::error::Error>> {
  println!("Starting server {}.", server_name);

  // set up our path variables
  let home_path = shellexpand::tilde("~");
  let server_directory_path = format!("{}/{}", home_path, server_name);
  let script_file_path = format!("{}/start.sh", server_directory_path);
  let eula_file_path = format!("{}/eula.txt", server_directory_path);

  // check if eula.txt exists - if it doesn't then warn the user they'll need to accept it and possibly modify server settings
  if !std::path::Path::new(&eula_file_path).exists() {
    println!("The eula.txt does not exist - you will need to accept the EULA located at {} by changing 'false' to 'true'.", eula_file_path);
    println!("This appears to be a new server instance. Don't forget to modify server.properties!");
  }

  // run the start command
  Command::new(script_file_path)
    .stdin(Stdio::null())
    .stdout(Stdio::null())
    .stderr(Stdio::null())
    .spawn()?;

  // return okay signal
  Ok(())
}
